Bloom Filter Trie: BFT_Root Struct Reference

Bloom Filter Trie

- Main Page
- Data Structures
- Files

- Data Structures
- Data Structure Index
- Data Fields

Data Fields
BFT_Root Struct Reference

Root vertex of a BFT. More...

## Data Fields
char ** | filenames
| Inserted genome file names. More...
uint64_t * | hash_v
uint16_t ** | skip_sp
annotation_array_elem * | comp_set_colors
info_per_level * | info_per_lvl
annotation_inform * | ann_inf
resultPresence * | res
int | k
| Size of k-mers. More...
int | r1
int | r2
int | nb_genomes
| Number of genomes inserted. More...
int | length_comp_set_colors
int | treshold_compression
| Color compression is triggered every BFT_Root::treshold_compression genome inserted. More...
uint8_t | compressed
uint8_t | marked
Node | node

## Detailed Description

Root vertex of a BFT.

A BFT_Root contains the k-mer size as well as the number and name of the inserted genomes. Other contained structures and variables are for internal use only and must not be modified.

## Field Documentation

char** BFT_Root::filenames

Inserted genome file names.

int BFT_Root::k

Size of k-mers.

int BFT_Root::nb_genomes

Number of genomes inserted.

It corresponds to the number of files stored in BFT_Root::filenames.

int BFT_Root::treshold_compression

Color compression is triggered every BFT_Root::treshold_compression genome inserted.

The documentation for this struct was generated from the following file:

- include/Node.h